@@ -7,7 +7,7 @@ from functools import partial
 from typing import Iterable
 
 import torch
-from accelerate import Accelerator
+from accelerate import Accelerator, DistributedType
 from torch.utils.data import DataLoader
 
 from pytorch_accelerated.callbacks import (
@@ -17,10 +17,13 @@ from pytorch_accelerated.callbacks import (
     TerminateOnNaNCallback,
     StopTrainingError,
     ProgressBarCallback,
+    MoveModulesToDeviceCallback,
 )
+from pytorch_accelerated.run_config import TrainerRunConfig
 from pytorch_accelerated.tracking import RunHistory, InMemoryRunHistory, LossTracker
 
 DEFAULT_CALLBACKS = (
+    MoveModulesToDeviceCallback,
     TerminateOnNaNCallback,
     PrintProgressCallback,
     ProgressBarCallback,
@@ -49,8 +52,8 @@ class TrainerPlaceholderValues(Enum):
     These placeholders will be replaced by the trainer with the correct values during training.
     """
 
-    NUM_EPOCHS = 'trainer.run_config["num_epochs"]'
-    NUM_UPDATE_STEPS_PER_EPOCH = 'trainer.run_config["num_update_steps_per_epoch"]'
+    NUM_EPOCHS = "trainer.run_config.num_epochs"
+    NUM_UPDATE_STEPS_PER_EPOCH = "trainer.run_config.num_update_steps_per_epoch"
     TRAIN_DATALOADER_LEN = "len(trainer._train_dataloader)"
     EVAL_DATALOADER_LEN = "len(trainer._eval_dataloader)"
 
@@ -109,6 +112,7 @@ class Trainer:
         :param run_history: an instance of a RunHistory subclass to track training runs. If this is not provided, a new one will be created.
 
         The callbacks that are used by default are (
+        :class:`~pytorch_accelerated.callbacks.MoveModulesToDeviceCallback`,
         :class:`~pytorch_accelerated.callbacks.TerminateOnNaNCallback`,
         :class:`~pytorch_accelerated.callbacks.PrintProgressCallback`,
         :class:`~pytorch_accelerated.callbacks.ProgressBarCallback`,
@@ -137,7 +141,7 @@ class Trainer:
         self._train_dl_kwargs = None
         self._eval_dl_kwargs = None
         self._eval_dataloader = None
-        self.run_config = None
+        self.run_config: TrainerRunConfig = None
 
         self.callback_handler.call_event("on_init_end", self)
 
@@ -239,7 +243,7 @@ class Trainer:
         return {
             "loss": loss,
             "model_outputs": model_outputs,
-            "batch_size": xb.size(0),
+            "batch_size": yb.size(0),
         }
 
     def backward_step(self, loss):
@@ -301,7 +305,7 @@ class Trainer:
         return {
             "loss": val_loss,
             "model_outputs": model_outputs,
-            "batch_size": xb.size(0),
+            "batch_size": yb.size(0),
         }
 
     def eval_epoch_end(self):
@@ -475,10 +479,18 @@ class Trainer:
             ),
         }
 
+    @property
+    def device(self):
+        """
+        Use the internal instance of :class:`accelerate.Accelerator` to get the appropriate device
+        :return: an instance of `torch.device`
+        """
+        return self._accelerator.device
+
     def _prepare_model_and_optimizer(self):
         """
         Uses the trainer's instance of :class:`accelerate.Accelerator` to wrap the model in any wrappers necessary for training.
-        (e.g. :class:`torch.distributed.DistributedDataParallel`) and ensures the parameters are placed on the appropriate device.
+        (e.g. :class:`torch.nn.parallel.DistributedDataParallel`) and ensures the parameters are placed on the appropriate device.
         """
         self._accelerator.free_memory()
         (self.model, self.optimizer,) = self._accelerator.prepare(
@@ -505,9 +517,9 @@ class Trainer:
         gradient_accumulation_steps,
         max_num_train_steps,
         gradient_clip_value,
-    ) -> dict:
+    ) -> TrainerRunConfig:
         """
-        Create a run config dictionary containing values representing the current state of the trainer.
+        Create an instance of :class:`~pytorch_accelerated.run_config.TrainerRunConfig` representing the current state of the trainer.
 
         :param per_device_batch_size: the batch size per device
         :param num_epochs: the number of epochs in the current training run
@@ -555,11 +567,14 @@ class Trainer:
             "max_num_train_steps": max_num_train_steps,
             "is_local_process_zero": self._accelerator.is_local_main_process,
             "is_world_process_zero": self._accelerator.is_main_process,
-            "fp16": self._accelerator.use_fp16,
+            "is_distributed": True
+            if self._accelerator.distributed_type != DistributedType.NO
+            else False,
+            "using_fp16": self._accelerator.use_fp16,
             "gradient_clip_value": gradient_clip_value,
         }
 
-        return config
+        return TrainerRunConfig(**config)
 
     def _run_training(self):
         """
@@ -570,7 +585,7 @@ class Trainer:
             "on_training_run_start",
             self,
         )
-        for epoch in range(self.run_config["num_epochs"]):
+        for epoch in range(self.run_config.num_epochs):
             try:
                 self._run_train_epoch(self._train_dataloader)
                 if self.eval_dataset is not None:
@@ -640,18 +655,18 @@ class Trainer:
                 self._accelerator.gather(batch_output["loss"]).detach().mean().item(),
                 batch_output["batch_size"],
             )
-            if self.run_config["gradient_accumulation_steps"] > 1:
-                batch_output["loss"] /= self.run_config["gradient_accumulation_steps"]
+            if self.run_config.gradient_accumulation_steps > 1:
+                batch_output["loss"] /= self.run_config.gradient_accumulation_steps
 
             self.callback_handler.call_event(
                 "on_train_step_end", self, batch_output=batch_output, batch=batch
             )
             self.backward_step(batch_output["loss"])
 
-            if self.run_config["gradient_clip_value"] is not None:
+            if self.run_config.gradient_clip_value is not None:
                 self._clip_gradients()
 
-            if (step + 1) % self.run_config["gradient_accumulation_steps"] == 0 or (
+            if (step + 1) % self.run_config.gradient_accumulation_steps == 0 or (
                 step + 1 == len(train_dl)
             ):
                 self.optimizer_step()
@@ -676,7 +691,7 @@ class Trainer:
         By default, this clips the gradients using :meth:`accelerate.Accelerator.clip_grad_value_`
         """
         self._accelerator.clip_grad_value_(
-            self.model.parameters(), clip_value=self.run_config["gradient_clip_value"]
+            self.model.parameters(), clip_value=self.run_config.gradient_clip_value
         )
 
     def _run_eval_epoch(self, valid_dl, is_training: bool = True):
